@@ -3,25 +3,43 @@ from pathlib import Path
 import gdown
 from functools import partial
 
-from tensorflow.keras.models import Model
-from tensorflow.keras.layers import Activation
-from tensorflow.keras.layers import BatchNormalization
-from tensorflow.keras.layers import Concatenate
-from tensorflow.keras.layers import Conv2D
-from tensorflow.keras.layers import Dense
-from tensorflow.keras.layers import Dropout
-from tensorflow.keras.layers import GlobalAveragePooling2D
-from tensorflow.keras.layers import Input
-from tensorflow.keras.layers import Lambda
-from tensorflow.keras.layers import MaxPooling2D
-from tensorflow.keras.layers import add
-from tensorflow.keras import backend as K
+import tensorflow as tf
+tf_version = int(tf.__version__.split(".")[0])
+
+if tf_version == 1:
+	from keras.models import Model
+	from keras.layers import Activation
+	from keras.layers import BatchNormalization
+	from keras.layers import Concatenate
+	from keras.layers import Conv2D
+	from keras.layers import Dense
+	from keras.layers import Dropout
+	from keras.layers import GlobalAveragePooling2D
+	from keras.layers import Input
+	from keras.layers import Lambda
+	from keras.layers import MaxPooling2D
+	from keras.layers import add
+	from keras import backend as K
+else:
+	from tensorflow.keras.models import Model
+	from tensorflow.keras.layers import Activation
+	from tensorflow.keras.layers import BatchNormalization
+	from tensorflow.keras.layers import Concatenate
+	from tensorflow.keras.layers import Conv2D
+	from tensorflow.keras.layers import Dense
+	from tensorflow.keras.layers import Dropout
+	from tensorflow.keras.layers import GlobalAveragePooling2D
+	from tensorflow.keras.layers import Input
+	from tensorflow.keras.layers import Lambda
+	from tensorflow.keras.layers import MaxPooling2D
+	from tensorflow.keras.layers import add
+	from tensorflow.keras import backend as K
 
 def scaling(x, scale):
 	return x * scale
 
-def InceptionResNetV2():
-	
+def InceptionResNetV2(dimension = 128):
+
 	inputs = Input(shape=(160, 160, 3))
 	x = Conv2D(32, 3, strides=2, padding='valid', use_bias=False, name= 'Conv2d_1a_3x3') (inputs)
 	x = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Conv2d_1a_3x3_BatchNorm')(x)
@@ -42,7 +60,7 @@ def InceptionResNetV2():
 	x = Conv2D(256, 3, strides=2, padding='valid', use_bias=False, name= 'Conv2d_4b_3x3') (x)
 	x = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Conv2d_4b_3x3_BatchNorm')(x)
 	x = Activation('relu', name='Conv2d_4b_3x3_Activation')(x)
-	
+
 	# 5x Block35 (Inception-ResNet-A block):
 	branch_0 = Conv2D(32, 1, strides=1, padding='same', use_bias=False, name= 'Block35_1_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block35_1_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
@@ -68,7 +86,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.17})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block35_1_Activation')(x)
-	
+
 	branch_0 = Conv2D(32, 1, strides=1, padding='same', use_bias=False, name= 'Block35_2_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block35_2_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block35_2_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -93,7 +111,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.17})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block35_2_Activation')(x)
-	
+
 	branch_0 = Conv2D(32, 1, strides=1, padding='same', use_bias=False, name= 'Block35_3_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block35_3_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block35_3_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -118,7 +136,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.17})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block35_3_Activation')(x)
-	
+
 	branch_0 = Conv2D(32, 1, strides=1, padding='same', use_bias=False, name= 'Block35_4_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block35_4_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block35_4_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -143,7 +161,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.17})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block35_4_Activation')(x)
-	
+
 	branch_0 = Conv2D(32, 1, strides=1, padding='same', use_bias=False, name= 'Block35_5_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block35_5_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block35_5_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -205,7 +223,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.1})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block17_1_Activation')(x)
-	
+
 	branch_0 = Conv2D(128, 1, strides=1, padding='same', use_bias=False, name= 'Block17_2_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block17_2_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block17_2_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -224,7 +242,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.1})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block17_2_Activation')(x)
-	
+
 	branch_0 = Conv2D(128, 1, strides=1, padding='same', use_bias=False, name= 'Block17_3_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block17_3_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block17_3_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -243,7 +261,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.1})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block17_3_Activation')(x)
-	
+
 	branch_0 = Conv2D(128, 1, strides=1, padding='same', use_bias=False, name= 'Block17_4_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block17_4_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block17_4_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -262,7 +280,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.1})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block17_4_Activation')(x)
-	
+
 	branch_0 = Conv2D(128, 1, strides=1, padding='same', use_bias=False, name= 'Block17_5_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block17_5_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block17_5_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -281,7 +299,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.1})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block17_5_Activation')(x)
-	
+
 	branch_0 = Conv2D(128, 1, strides=1, padding='same', use_bias=False, name= 'Block17_6_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block17_6_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block17_6_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -299,8 +317,8 @@ def InceptionResNetV2():
 	up = Conv2D(896, 1, strides=1, padding='same', use_bias=True, name= 'Block17_6_Conv2d_1x1') (mixed)
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.1})(up)
 	x = add([x, up])
-	x = Activation('relu', name='Block17_6_Activation')(x)	
-	
+	x = Activation('relu', name='Block17_6_Activation')(x)
+
 	branch_0 = Conv2D(128, 1, strides=1, padding='same', use_bias=False, name= 'Block17_7_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block17_7_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block17_7_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -319,7 +337,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.1})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block17_7_Activation')(x)
-	
+
 	branch_0 = Conv2D(128, 1, strides=1, padding='same', use_bias=False, name= 'Block17_8_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block17_8_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block17_8_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -338,7 +356,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.1})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block17_8_Activation')(x)
-	
+
 	branch_0 = Conv2D(128, 1, strides=1, padding='same', use_bias=False, name= 'Block17_9_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block17_9_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block17_9_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -357,7 +375,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.1})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block17_9_Activation')(x)
-	
+
 	branch_0 = Conv2D(128, 1, strides=1, padding='same', use_bias=False, name= 'Block17_10_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block17_10_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block17_10_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -377,7 +395,7 @@ def InceptionResNetV2():
 	x = add([x, up])
 	x = Activation('relu', name='Block17_10_Activation')(x)
 
-	# Mixed 7a (Reduction-B block): 8 x 8 x 2080	
+	# Mixed 7a (Reduction-B block): 8 x 8 x 2080
 	branch_0 = Conv2D(256, 1, strides=1, padding='same', use_bias=False, name= 'Mixed_7a_Branch_0_Conv2d_0a_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Mixed_7a_Branch_0_Conv2d_0a_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Mixed_7a_Branch_0_Conv2d_0a_1x1_Activation')(branch_0)
@@ -404,7 +422,7 @@ def InceptionResNetV2():
 	x = Concatenate(axis=3, name='Mixed_7a')(branches)
 
 	# 5x Block8 (Inception-ResNet-C block):
-	
+
 	branch_0 = Conv2D(192, 1, strides=1, padding='same', use_bias=False, name= 'Block8_1_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block8_1_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block8_1_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -423,7 +441,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.2})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block8_1_Activation')(x)
-	
+
 	branch_0 = Conv2D(192, 1, strides=1, padding='same', use_bias=False, name= 'Block8_2_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block8_2_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block8_2_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -442,7 +460,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.2})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block8_2_Activation')(x)
-	
+
 	branch_0 = Conv2D(192, 1, strides=1, padding='same', use_bias=False, name= 'Block8_3_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block8_3_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block8_3_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -461,7 +479,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.2})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block8_3_Activation')(x)
-	
+
 	branch_0 = Conv2D(192, 1, strides=1, padding='same', use_bias=False, name= 'Block8_4_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block8_4_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block8_4_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -480,7 +498,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.2})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block8_4_Activation')(x)
-	
+
 	branch_0 = Conv2D(192, 1, strides=1, padding='same', use_bias=False, name= 'Block8_5_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block8_5_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block8_5_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -499,7 +517,7 @@ def InceptionResNetV2():
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 0.2})(up)
 	x = add([x, up])
 	x = Activation('relu', name='Block8_5_Activation')(x)
-	
+
 	branch_0 = Conv2D(192, 1, strides=1, padding='same', use_bias=False, name= 'Block8_6_Branch_0_Conv2d_1x1') (x)
 	branch_0 = BatchNormalization(axis=3, momentum=0.995, epsilon=0.001, scale=False, name='Block8_6_Branch_0_Conv2d_1x1_BatchNorm')(branch_0)
 	branch_0 = Activation('relu', name='Block8_6_Branch_0_Conv2d_1x1_Activation')(branch_0)
@@ -517,12 +535,12 @@ def InceptionResNetV2():
 	up = Conv2D(1792, 1, strides=1, padding='same', use_bias=True, name= 'Block8_6_Conv2d_1x1') (mixed)
 	up = Lambda(scaling, output_shape=K.int_shape(up)[1:], arguments={'scale': 1})(up)
 	x = add([x, up])
-	
+
 	# Classification block
 	x = GlobalAveragePooling2D(name='AvgPool')(x)
 	x = Dropout(1.0 - 0.8, name='Dropout')(x)
 	# Bottleneck
-	x = Dense(128, use_bias=False, name='Bottleneck')(x)
+	x = Dense(dimension, use_bias=False, name='Bottleneck')(x)
 	x = BatchNormalization(momentum=0.995, epsilon=0.001, scale=False, name='Bottleneck_BatchNorm')(x)
 
 	# Create model
@@ -530,23 +548,25 @@ def InceptionResNetV2():
 
 	return model
 
-def loadModel(url = 'https://drive.google.com/uc?id=1971Xk5RwedbudGgTIrGAL4F7Aifu7id1'):
+#url = 'https://drive.google.com/uc?id=1971Xk5RwedbudGgTIrGAL4F7Aifu7id1'
+
+def loadModel(url = 'https://github.com/serengil/deepface_models/releases/download/v1.0/facenet_weights.h5'):
 	model = InceptionResNetV2()
-	
+
 	#-----------------------------------
-	
+
 	home = str(Path.home())
-	
+
 	if os.path.isfile(home+'/.deepface/weights/facenet_weights.h5') != True:
 		print("facenet_weights.h5 will be downloaded...")
-		
+
 		output = home+'/.deepface/weights/facenet_weights.h5'
 		gdown.download(url, output, quiet=False)
-	
+
 	#-----------------------------------
-	
+
 	model.load_weights(home+'/.deepface/weights/facenet_weights.h5')
-	
+
 	#-----------------------------------
-	
-	return model
\ No newline at end of file
+
+	return model
